==> asksuite-core-1.0.100.tgz: package/test.js <==
let KeywordMatcher = require('./keyword_interpreter/keyword-matcher')({API_AI_DEVELOPER: "1c3021ef639e45428f8ae544ab9f7331"})
const ExpressionBuilder = require('./keyword_interpreter/expression-builder')
const Intent = require('./keyword_interpreter/intent-model')

let intent = new Intent("cotacao");
intent.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent.addExpression(ExpressionBuilder.newInstance().contains().date());
intent.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent2 = new Intent("cotacao_pessoas");
intent2.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent2.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("substantivo_pessoas"));
intent2.addExpression(ExpressionBuilder.newInstance().contains().number());
intent2.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent3 = new Intent("cotacao_grupo");
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_grupo"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("substantivo_pessoas"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().number());
intent3.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent4 = new Intent("dayuse");
intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_dayuse"));


let intent5 = new Intent("cadeirante");
intent5.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subs_cadeirante"));


let intent6 = new Intent("curriculium");
intent6.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_curriculo"));
// intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_dayuse"));


let expressions = [intent];


//
async function execute() {

    // let cont = 0;

    let obj = {
        "text": "Quanto esta Pacote. Para 5 dias...casal? Como vai??? quero ir viajar?",
        "intents": [{
            "id": 3,
            "intent": "cotacao_num_pessoas",
            "expressions": [{
                "entity": "preco",
                "operation": "contains",
                "entityType": "dialogFlow"
            }, {
                "entity": "substantivo_pessoas",
                "operation": "contains",
                "entityType": "dialogFlow"
            }, {
                "entity": "subst_dayuse",
                "operation": "not_contains",
                "entityType": "dialogFlow"
            }, {
                "entity": "Subst_pacotes_promocoes",
                "operation": "not_contains",
                "entityType": "dialogFlow"
            }, {"entity": "subst_grupo", "operation": "not_contains", "entityType": "dialogFlow"}],
            "examples": [{
                "text": "Olá Gostaria de saber os valores para julho, para um casal com dois filhos.",
                "match": true
            }, {"text": "Quanto esta o pacote...Para 5 dias...casal", "match": null}]
        }]
    }

    // let globalCache = await KeywordMatcher.refreshCache();

    // let globalCache = await KeywordMatcher.refreshCache();

    // let base = await KeywordMatcher.getIntent(obj.text, obj.intents, globalCache)
    // // let newString = obj.text.replace(/[&#,+()$~%.'":*?<>{}]/g, ' ');
    // // var newStr = newString.replace(/\s+/g, ' ');
    //
    // console.log(base)


}

//
// execute();

==> asksuite-core-1.0.102.tgz: package/test.js <==
let KeywordMatcher = require('./keyword_interpreter/keyword-matcher')({API_AI_DEVELOPER: "1c3021ef639e45428f8ae544ab9f7331"})
const ExpressionBuilder = require('./keyword_interpreter/expression-builder')
const Intent = require('./keyword_interpreter/intent-model')

let intent = new Intent("cotacao");
intent.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent.addExpression(ExpressionBuilder.newInstance().contains().date());
intent.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent2 = new Intent("cotacao_pessoas");
intent2.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent2.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("substantivo_pessoas"));
intent2.addExpression(ExpressionBuilder.newInstance().contains().number());
intent2.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent3 = new Intent("cotacao_grupo");
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_grupo"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("substantivo_pessoas"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().number());
intent3.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent4 = new Intent("dayuse");
intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_dayuse"));


let intent5 = new Intent("cadeirante");
intent5.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subs_cadeirante"));


let intent6 = new Intent("curriculium");
intent6.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_curriculo"));
// intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_dayuse"));


let expressions = [intent];


//
async function execute() {

    // let cont = 0;

    // let obj = {
    //     "text": "Quanto esta Pacote. Para 5 dias...casal? Como vai??? quero ir viajar?",
    //     "intents": [{
    //         "id": 3,
    //         "intent": "cotacao_num_pessoas",
    //         "expressions": [{
    //             "entity": "preco",
    //             "operation": "contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "substantivo_pessoas",
    //             "operation": "contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "subst_dayuse",
    //             "operation": "not_contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "Subst_pacotes_promocoes",
    //             "operation": "not_contains",
    //             "entityType": "dialogFlow"
    //         }, {"entity": "subst_grupo", "operation": "not_contains", "entityType": "dialogFlow"}],
    //         "examples": [{
    //             "text": "Olá Gostaria de saber os valores para julho, para um casal com dois filhos.",
    //             "match": true
    //         }, {"text": "Quanto esta o pacote...Para 5 dias...casal", "match": null}]
    //     }]
    // }

    // let globalCache = await KeywordMatcher.refreshCache();

    // let globalCache = await KeywordMatcher.refreshCache();

    // let base = await KeywordMatcher.getIntent(obj.text, obj.intents, globalCache)
    // // let newString = obj.text.replace(/[&#,+()$~%.'":*?<>{}]/g, ' ');
    // // var newStr = newString.replace(/\s+/g, ' ');
    //
    // console.log(base)


    let obj = {
        "text": "Tens vaga para amanhã?",
        "intents": [{
            "id": 16,
            "intent": "cotacao_amanha_horario",
            "expressions": [{
                "entity": "preco",
                "operation": "contains",
                "entityType": "dialogFlow"
            }, {
                "entity": "subst_hoje_amanha",
                "operation": "contains",
                "entityType": "dialogFlow"
            }, {"entity": "subst_dayuse", "operation": "not_contains", "entityType": "dialogFlow"}],
            "examples": [{
                "text": "Quanto está a diária para hoje? Na verdade, vamos entrar às 19h e sair às 5h",
                "match": true
            }, {"text": "Tens vaga para amanhã?", "match": null}]
        }]
    }

    let globalCache = await KeywordMatcher.refreshCache();

    let base = await KeywordMatcher.getIntent(obj.text, obj.intents, globalCache)
    // let newString = obj.text.replace(/[&#,+()$~%.'":*?<>{}]/g, ' ');
    // var newStr = newString.replace(/\s+/g, ' ');

    console.log(base)

}

//
// execute();
